# pysikui
Fast cross-platform python module for gui automation

For macos:
+ playsound dependencies
+ + macOS/Homebrew: brew install cairo pkg-config


For linux:
+ playsound dependencies
+ + Ubuntu/Debian: sudo apt install libgirepository1.0-dev libcairo2-dev
+ + Arch Linux: sudo pacman -S cairo pkgconf
+ + Fedora: sudo dnf install cairo-devel pkg-config python3-devel
+ + penSUSE: sudo zypper install cairo-devel pkg-config python3-devel

+ (evdev): sudo apt-get install python3-dev or python3.x, where x is version of your python

it is recommended to install these VS Code addons: `Paste Image`, `Image preview`